<?php
/**
 * @copyright	Copyright (c) 2016 AmyTheme (http://www.amytheme.com). All rights reserved.
 * @license		http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
 */

defined('ABSPATH') or die;

/**
 * Get sidebar name.
 */
if (! function_exists('amy_movie_get_sidebar_name')) {
	function amy_movie_get_sidebar_name($name) {
		if (empty($GLOBALS['wp_registered_sidebars'])) {
			return $name;
		}

		$sidebars	= get_option('stag_custom_sidebars');
		$taken		= array();

		foreach ($GLOBALS['wp_registered_sidebars'] as $sidebar) {
			$taken[]	= $sidebar['name'];
		}

		if (empty($sidebars)) {
			$sidebars	= array();
		}

		$taken	= array_merge($taken, $sidebars);

		if (in_array($name, $taken)) {
			$counter 	= substr($name, -1);

			if (! is_numeric($counter)) {
				$new_name	= $name . ' 1';
			} else {
				$new_name	= substr($name, 0, -1) . ((int) $counter + 1);
			}

			$name = amy_movie_get_sidebar_name($new_name);
		}

		return $name;
	}
}

/**
 * Get registered sidebars
 */
if (! function_exists('amy_movie_wp_registered_sidebars')) {
	function amy_movie_wp_registered_sidebars() {
		global $wp_registered_sidebars;

		$widgets	= array();

		if (! empty($wp_registered_sidebars)) {
			foreach ($wp_registered_sidebars as $key => $value) {
				$widgets[ $key ]	= $value['name'];
			}
		}

		return array_reverse($widgets);
	}
}

/**
 * Check Google Fonts
 */
if (! function_exists('amy_movie_is_google_font')) {
	function amy_movie_is_google_font($font_family) {
		static $google_fonts;

		if (empty($google_fonts)) {
			$google_json	= amy_get_google_fonts();

			if (is_object($google_json)) {
				$google_fonts	= array();

				foreach ($google_json->items as $key => $font) {
					$google_fonts[ $font->family ]	= $font->variants;
				}
			}
		}

		return is_array($google_fonts) && array_key_exists($font_family, $google_fonts);
	}
}

/**
 * Enqueue Google Fonts.
 */
if (! function_exists('amy_movie_enqueue_google_fonts')) {
	function amy_movie_enqueue_google_fonts() {
		$embed_fonts	= array();
		$query_args		= array();
		$subsets		= amy_get_option('subsets');
		$subsets		= ! empty($subsets) ? '&subset=' . implode(',', $subsets) : '';
		$typography		= amy_get_option('typography');
		$google_json	= amy_get_google_fonts();

		if (empty($typography)) {
			return;
		}

		foreach ($typography as $font) {
			if (! empty($font['selector'])) {
				if (amy_movie_is_google_font($font['font']['family'])) {
					$family		= $font['font']['family'];
					$variant	= $font['font']['variant'] != 'regular' ? $font['font']['variant'] : 400;
					$embed_fonts[ $family ]['variant'][ $variant ]	= $variant;
				}
			}
		}

		if (! empty($embed_fonts)) {
			foreach ($embed_fonts as $name => $font) {
				$variants		= $font['variant'];
				$embed_variants	= ! empty($font['variant']) ? ':' . implode(',', $font['variant']) : '';
				$query_args[]	= $name . $embed_variants;
			}

			wp_enqueue_style('amy-movie-google-fonts', esc_url(add_query_arg('family', urlencode(implode('|', $query_args)) . $subsets, '//fonts.googleapis.com/css')));
		}
	}
}

/*
 * Get all custom sizes of image
 */
if (! function_exists('amy_movie_get_image_sizes')) {
	function amy_movie_get_image_sizes($force = false, $flip = true) {
		$current_image_sizes	= get_intermediate_image_sizes();

		foreach ($current_image_sizes as $image_size) {
			$dimenssion					= (in_array($image_size, array('thumbnail', 'medium', 'large'))) ? ' - (' . get_option($image_size . '_size_w') . 'x' . get_option($image_size . '_size_h') . ')' : '';
			$image_sizes[ $image_size ]	= $image_size . $dimenssion;
		}

		if ($force) {
			$get_custom_image_sizes	= amy_get_option('custom_image_sizes');

			if (! empty($get_custom_image_sizes)) {
				foreach ($get_custom_image_sizes as $custom_size) {
					$name						= sanitize_title($custom_size['img_size_name']);
					$custom_image_sizes[ $name ]	= $name . ' - (' . $custom_size['img_size_width'] . 'x' . $custom_size['img_size_height'] . ')';
				}

				$image_sizes	= array_filter(array_merge($image_sizes, $custom_image_sizes));
			}
		}

		$image_sizes['full']	= 'full (orginal size)';
		$image_sizes			= ($flip) ? array_flip($image_sizes) : $image_sizes;

		return apply_filters('amy_movie_custom_image_sizes', $image_sizes);
	}
}

/**
 * encapsulates post-classes to use them on different tags
 */
if (! function_exists('amy_movie_get_post_classes')) {
	function amy_movie_get_post_classes($classes = array()) {
		// Adds a class for microformats v2
		$classes[] = 'h-entry';

		// add hentry to the same tag as h-entry
		$classes[] = 'hentry';

		// adds microformats 2 activity-stream support
		// for pages and articles
		if (get_post_type() === 'page') {
			$classes[] = 'h-as-page';
		}
		if (! get_post_format() && 'post' === get_post_type()) {
			$classes[] = 'h-as-article';
		}

		// adds some more microformats 2 classes based on the
		// posts "format"
		switch (get_post_format()) {
			case 'aside':
			case 'status':
				$classes[] = 'h-as-note';
				break;
			case 'audio':
				$classes[] = 'h-as-audio';
				break;
			case 'video':
				$classes[] = 'h-as-video';
				break;
			case 'gallery':
			case 'image':
				$classes[] = 'h-as-image';
				break;
			case 'link':
				$classes[] = 'h-as-bookmark';
				break;
		}

		return array_unique($classes);
	}
}

/**
 * add semantics
 *
 * @param string $id the class identifier
 * @return array
 */
if (! function_exists('amy_movie_get_semantics')) {
	function amy_movie_get_semantics($id = null) {
		$classes = array();

		// add default values
		switch ($id) {
			case 'body':
				if (! is_singular()) {
					$classes['itemscope'] 	= array('');
					$classes['itemtype'] 	= array('http://schema.org/Blog');
				} elseif (is_single()) {
					$classes['itemscope'] 	= array('');
					$classes['itemtype'] 	= array('http://schema.org/BlogPosting');
				} elseif (is_page()) {
					$classes['itemscope'] 	= array('');
					$classes['itemtype'] 	= array('http://schema.org/WebPage');
				}

				break;
			case 'site-title':
				if (! is_singular()) {
					$classes['itemprop'] 	= array('name');
					$classes['class'] 		= array('p-name');
				}

				break;
			case 'site-description':
				if (! is_singular()) {
					$classes['itemprop'] 	= array('description');
					$classes['class'] 		= array('p-summary', 'e-content');
				}

				break;
			case 'site-url':
				if (! is_singular()) {
					$classes['itemprop'] 	= array('url');
					$classes['class'] 		= array('u-url', 'url');
				}

				break;
			case 'post':
				if (! is_singular()) {
					$classes['itemprop'] 	= array('blogPost');
					$classes['itemscope'] 	= array('');
					$classes['itemtype'] 	= array('http://schema.org/BlogPosting');
				}

				break;
		}

		$classes = apply_filters('amy_movie_semantics', $classes, $id);
		$classes = apply_filters("amy_movie_semantics_{$id}", $classes, $id);

		return $classes;
	}
}

/**
 * echos the semantic classes added via
 *
 * @param string $id the class identifier
 */
if (! function_exists('amy_movie_semantics')) {
	function amy_movie_semantics($id) {
		$classes = amy_movie_get_semantics($id);

		if (! $classes) {
			return;
		}

		foreach ($classes as $key => $value) {
			echo ' ' . esc_attr($key) . '="' . esc_attr(join(' ', $value)) . '"';
		}
	}
}

/*
 * Social List
 */
if (! function_exists('amy_movie_social_list')) {
	function amy_movie_social_list() {
		$fb_link 	= amy_get_option('facebook_url');
		$tw_link 	= amy_get_option('twitter_url');
		$gg_link 	= amy_get_option('google_url');
		$printerest = amy_get_option('pinterest_url');

		$html = '<ul class="amy-social-list">';

		if ($fb_link) {
			$html .= '<li><a href="' . esc_url($fb_link) . '" class="fa fa-facebook"></a></li>';
		}

		if ($tw_link) {
			$html .= '<li><a href="' . esc_url($tw_link) . '" class="fa fa-twitter"></a></li>';
		}

		if ($gg_link) {
			$html .= '<li><a href="' . esc_url($gg_link) . '" class="fa fa-google-plus"></a></li>';
		}

		if ($printerest) {
			$html .= '<li><a href="' . esc_url($printerest) . '" class="fa fa-pinterest"></a></li>';
		}

		$html .= '</ul>';

		return $html;
	}
}

/*
 * Login / Register
 */

if (! function_exists('amy_movie_user')) {
	function amy_movie_user() {
		$html  = '<div class="box-user">';

		if (is_user_logged_in()) {
			$current_user = wp_get_current_user();
			$html .= '<span>' . esc_html__('Hello ', 'amy-movie') . $current_user->display_name . ',</span>';
			$html .= '<a href="' . wp_logout_url() . '">' . esc_html__('Log Out', 'amy-movie') . '</a>';
		} else {
			if (function_exists('amy_user_popup')) {
				$html .= amy_user_popup();
			} else {
				$html .= '<a href="' . esc_url(home_url('/wp-login.php')) . '"><i aria-hidden="true" class="fa fa-user"></i>' . esc_html__('Login', 'amy-movie') . '</a>';

				if (get_option('users_can_register')) {
					$html	.= '<a href="' . esc_url(home_url('/wp-login.php?action=register')) . '">' . esc_html__('Register', 'amy-movie') . '</a>';
				}
			}
		}

		$html .= '</div>';

		return $html;
	}
}

/*
 * Show Menu by ID
 */
if (! function_exists('amy_movie_menu_item')) {
	function amy_movie_menu_item($slug) {
		$menu = wp_get_nav_menu_items($slug);

		$html  = '<div class="amy-menu">';
		$html .= '<ul class="menu">';

		if (!empty($menu)) {
			foreach ($menu as $item) {
				$html .= '<li class="menu-item">';
				$html .= '<a href="' . esc_url($item->url) . '">' . esc_attr($item->title) . '</a>';
				$html .= '</li>';
			}
		}

		$html .= '</ul></div>';

		return $html;
	}
}

/*
 * Default Image Size
 */
if (! function_exists('amy_movie_default_image_size')) {
	function amy_movie_default_image_size() {
		$img_size = array();

		$img_size[0]['img_size_name'] 	= 'Movie Widget List';
		$img_size[0]['img_size_width'] 	= '118';
		$img_size[0]['img_size_height']	= '159';
		$img_size[0]['img_crop'] 		= '1';

		$img_size[1]['img_size_name'] 	= 'Blog Widget List';
		$img_size[1]['img_size_width'] 	= '120';
		$img_size[1]['img_size_height']	= '85';
		$img_size[1]['img_crop'] 		= '1';

		$img_size[2]['img_size_name'] 	= 'Blog Masonry Size 1';
		$img_size[2]['img_size_width'] 	= '360';
		$img_size[2]['img_size_height']	= '240';
		$img_size[2]['img_crop'] 		= '1';

		$img_size[3]['img_size_name'] 	= 'Blog Masonry Size 2';
		$img_size[3]['img_size_width'] 	= '360';
		$img_size[3]['img_size_height']	= '430';
		$img_size[3]['img_crop'] 		= '1';

		$img_size[4]['img_size_name'] 	= 'Blog Masonry Size 3';
		$img_size[4]['img_size_width'] 	= '750';
		$img_size[4]['img_size_height']	= '430';
		$img_size[4]['img_crop'] 		= '1';

		$img_size[5]['img_size_name'] 	= 'amy-movie-v2-132-220-crop-shortcode-movie-grid-2-column-4';
		$img_size[5]['img_size_width'] 	= '132';
		$img_size[5]['img_size_height']	= '220';
		$img_size[5]['img_crop'] 		= '1';

		$img_size[6]['img_size_name'] 	= 'amy-movie-v2-264-454-crop-single-movie-layout-2';
		$img_size[6]['img_size_width'] 	= '264';
		$img_size[6]['img_size_height']	= '454';
		$img_size[6]['img_crop'] 		= '1';

		$img_size[7]['img_size_name'] 	= 'amy-movie-v2-74-58-crop-widget-list';
		$img_size[7]['img_size_width'] 	= '74';
		$img_size[7]['img_size_height']	= '58';
		$img_size[7]['img_crop'] 		= '1';

		$img_size[8]['img_size_name'] 	= 'amy-movie-v2-50-70-crop-tralier-list';
		$img_size[8]['img_size_width'] 	= '50';
		$img_size[8]['img_size_height']	= '70';
		$img_size[8]['img_crop'] 		= '1';

		$img_size[9]['img_size_name'] 	= 'amy-movie-v2-114-78-crop-widget-list-2';
		$img_size[9]['img_size_width'] 	= '114';
		$img_size[9]['img_size_height']	= '78';
		$img_size[9]['img_crop'] 		= '1';

		$img_size[10]['img_size_name'] 	= 'amy-movie-v2-264-396-crop-showtime-1';
		$img_size[10]['img_size_width'] = '264';
		$img_size[10]['img_size_height']= '396';
		$img_size[10]['img_crop'] 		= '1';

		$img_size[11]['img_size_name'] 	= 'amy-movie-v2-196-294-crop-showtime-4';
		$img_size[11]['img_size_width'] = '196';
		$img_size[11]['img_size_height']= '294';
		$img_size[11]['img_crop'] 		= '1';

		$img_size[12]['img_size_name'] 	= 'amy-movie-v2-214-321-crop-showtime-3';
		$img_size[12]['img_size_width'] = '214';
		$img_size[12]['img_size_height']= '321';
		$img_size[12]['img_crop'] 		= '1';

		$img_size[13]['img_size_name'] 	= 'amy-movie-v2-132-198-crop-widget-movie';
		$img_size[13]['img_size_width'] = '132';
		$img_size[13]['img_size_height']= '198';
		$img_size[13]['img_crop'] 		= '1';

		$img_size[14]['img_size_name'] 	= 'amy-movie-v2-464-340-crop-gallery';
		$img_size[14]['img_size_width'] = '464';
		$img_size[14]['img_size_height']= '340';
		$img_size[14]['img_crop'] 		= '1';

		$img_size[15]['img_size_name'] 	= 'amy-movie-v2-754-400-crop-blog-list';
		$img_size[15]['img_size_width'] = '754';
		$img_size[15]['img_size_height']= '400';
		$img_size[15]['img_crop'] 		= '1';

		$img_size[16]['img_size_name'] 	= 'amy-movie-v2-422-298-crop-gallery-carousel';
		$img_size[16]['img_size_width'] 	= '422';
		$img_size[16]['img_size_height']	= '298';
		$img_size[16]['img_crop'] 		= '1';

		$img_size[17]['img_size_name'] 	= 'amy-movie-v2-174-300-crop-shortcode-movie-carousel-1';
		$img_size[17]['img_size_width'] = '174';
		$img_size[17]['img_size_height']= '300';
		$img_size[17]['img_crop'] 		= '1';

		$img_size[18]['img_size_name'] 	= 'amy-movie-v2-258-444-crop-shortcode-movie-carousel-2';
		$img_size[18]['img_size_width'] = '258';
		$img_size[18]['img_size_height']= '444';
		$img_size[18]['img_crop'] 		= '1';

		$img_size[19]['img_size_name'] 	= 'amy-movie-v2-214-368-crop-shortcode-movie-carousel-3';
		$img_size[19]['img_size_width'] = '214';
		$img_size[19]['img_size_height']= '368';
		$img_size[19]['img_crop'] 		= '1';

		$img_size[20]['img_size_name'] 	= 'amy-movie-v2-196-336-crop-shortcode-movie-grid-2-column-2';
		$img_size[20]['img_size_width'] = '196';
		$img_size[20]['img_size_height']= '336';
		$img_size[20]['img_crop'] 		= '1';
		
		return $img_size;
	}
}

/**
 * Get array value.
 */
if (!function_exists('amy_movie_get_array_value')) {
	function amy_movie_get_array_value($array, $key, $default = null) {
		return isset($array[$key]) ? $array[$key] : $default;
	}
}

/**
 * Get fieldset option
 */
if (!function_exists('amy_movie_get_fieldset_option')) {
	function amy_movie_get_fieldset_option($option_name = '', $key = '', $default = '') {
		$options = amy_get_option($option_name);

		return isset($options[$key]) ? $options[$key] : $default;
	}
}

/**
 * Custom style for background.
 */
if (!function_exists('amy_movie_background_css')) {
	function amy_movie_background_css($selector, $background = array()) {
		$builder	= AmyFramework_Style_Builder::getInstance();

		$image		= amy_movie_get_array_value($background, 'image');
		$repeat		= amy_movie_get_array_value($background, 'repeat');
		$position	= amy_movie_get_array_value($background, 'position');
		$attachment	= amy_movie_get_array_value($background, 'attachment');
		$size		= amy_movie_get_array_value($background, 'size');
		$color		= amy_movie_get_array_value($background, 'color');

		if ($image) {
			$builder->addStyle($selector, 'background-image: url(' . $image . ')');
		}

		if ($repeat) {
			$builder->addStyle($selector, 'background-repeat:' . $repeat);
		}

		if ($position) {
			$builder->addStyle($selector, 'background-position:' . $position);
		}

		if ($attachment) {
			$builder->addStyle($selector, 'background-attachment:' . $attachment);
		}

		if ($size) {
			$builder->addStyle($selector, 'background-size: ' . $size);
		}

		if ($color) {
			$builder->addStyle($selector, 'background-color: ' . $color);
		}
	}
}


if (!function_exists('amy_movie_defaults_fields')) {
	function amy_movie_defaults_fields() {
		$default = array(
			'movie_release',
			'movie_duration',
			'movie_imdb',
			'movie_mpaa',
			'movie_language',
			'movie_genre',
			'movie_actor',
			'movie_director'
		);

		return $default;
	}
}

/*
 * Get Cinema
 */
if (! function_exists('amy_movie_get_cinema')) {
	function amy_movie_get_cinema() {
		$cinema_list = get_posts(array(
			'posts_per_page'	=> -1,
			'post_type'		=> 'amy_cinema',
			'post_status'   => 'publish',
		));

		return $cinema_list;
	}
}

// Get List Tvshows
if (! function_exists('amy_movie_get_list_tvshow')) {
	function amy_movie_get_list_tvshow() {
		$list = get_posts(array(
			'posts_per_page'	=> -1,
			'post_type'		=> 'amy_tvshow',
			'post_status'   => 'publish',
		));

		return $list;
	}
}

// Get List Season
if (! function_exists('amy_movie_get_list_season')) {
	function amy_movie_get_list_season() {
		$list = get_posts(array(
			'posts_per_page'	=> -1,
			'post_type'		=> 'amy_season',
			'post_status'   => 'publish',
		));

		return $list;
	}
}